__version__ = '1.0.6'

# next base
from jsw_nx.base.filter import filter
from jsw_nx.base.find import find
from jsw_nx.base.find_index import find_index
from jsw_nx.base.foreach import foreach
from jsw_nx.base.forin import forin
from jsw_nx.base.get import get
from jsw_nx.base.includes import includes
from jsw_nx.base.index import index
from jsw_nx.base.map import map
from jsw_nx.base.mix import mix
from jsw_nx.base.reduce import reduce
from jsw_nx.base.set import set


# ruby style
from jsw_nx.rubify.times import times
from jsw_nx.rubify.to_a import to_a
from jsw_nx.rubify.to_b import to_b
from jsw_nx.rubify.to_f import to_f
from jsw_nx.rubify.to_i import to_i
from jsw_nx.rubify.to_n import to_n
from jsw_nx.rubify.to_s import to_s

# next packages
from jsw_nx.packages.days import days
